pub struct BufWriter<W>{ /* private fields */ }alloc_io)Expand description
Wraps a writer and buffers its output.
It can be excessively inefficient to work directly with something that
implements Write. For example, every call to
write on TcpStream results in a system call. A
BufWriter<W> keeps an in-memory buffer of data and writes it to an underlying
writer in large, infrequent batches.
BufWriter<W> can improve the speed of programs that make small and
repeated write calls to the same file or network socket. It does not
help when writing very large amounts at once, or writing just one or a few
times. It also provides no advantage when writing to a destination that is
in memory, like a Vec<u8>.
It is critical to call flush before BufWriter<W> is dropped. Though
dropping will attempt to flush the contents of the buffer, any errors
that happen in the process of dropping will be ignored. Calling flush
ensures that the buffer is empty and thus dropping will not even attempt
file operations.
Examples
Letโs write the numbers one through ten to a TcpStream:
use std::io::prelude::*;
use std::net::TcpStream;
let mut stream = TcpStream::connect("127.0.0.1:34254").unwrap();
for i in 0..10 {
stream.write(&[i+1]).unwrap();
}Because weโre not buffering, we write each one in turn, incurring the
overhead of a system call per byte written. We can fix this with a
BufWriter<W>:
use std::io::prelude::*;
use std::io::BufWriter;
use std::net::TcpStream;
let mut stream = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
for i in 0..10 {
stream.write(&[i+1]).unwrap();
}
stream.flush().unwrap();By wrapping the stream with a BufWriter<W>, these ten writes are all grouped
together by the buffer and will all be written out in one system call when
the stream is flushed.
Implementations
Sourceimpl<W> BufWriter<W>where
W: Write,
impl<W> BufWriter<W>where
W: Write,
1.0.0 ยท Sourcepub fn new(inner: W) -> BufWriter<W> โ
pub fn new(inner: W) -> BufWriter<W> โ
Creates a new BufWriter<W> with a default buffer capacity. The default is currently 8 KiB,
but may change in the future.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let mut buffer = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());1.0.0 ยท Sourcepub fn with_capacity(capacity: usize, inner: W) -> BufWriter<W> โ
pub fn with_capacity(capacity: usize, inner: W) -> BufWriter<W> โ
Creates a new BufWriter<W> with at least the specified buffer capacity.
Examples
Creating a buffer with a buffer of at least a hundred bytes.
use std::io::BufWriter;
use std::net::TcpStream;
let stream = TcpStream::connect("127.0.0.1:34254").unwrap();
let mut buffer = BufWriter::with_capacity(100, stream);1.0.0 ยท Sourcepub fn into_inner(self) -> Result<W, IntoInnerError<BufWriter<W>>>
pub fn into_inner(self) -> Result<W, IntoInnerError<BufWriter<W>>>
Unwraps this BufWriter<W>, returning the underlying writer.
The buffer is written out before returning the writer.
Errors
An Err will be returned if an error occurs while flushing the buffer.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let mut buffer = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
// unwrap the TcpStream and flush the buffer
let stream = buffer.into_inner().unwrap();1.56.0 ยท Sourcepub fn into_parts(self) -> (W, Result<Vec<u8>, WriterPanicked>)
pub fn into_parts(self) -> (W, Result<Vec<u8>, WriterPanicked>)
Disassembles this BufWriter<W>, returning the underlying writer, and any buffered but
unwritten data.
If the underlying writer panicked, it is not known what portion of the data was written.
In this case, we return WriterPanicked for the buffered data (from which the buffer
contents can still be recovered).
into_parts makes no attempt to flush data and cannot fail.
Examples
use std::io::{BufWriter, Write};
let mut buffer = [0u8; 10];
let mut stream = BufWriter::new(buffer.as_mut());
write!(stream, "too much data").unwrap();
stream.flush().expect_err("it doesn't fit");
let (recovered_writer, buffered_data) = stream.into_parts();
assert_eq!(recovered_writer.len(), 0);
assert_eq!(&buffered_data.unwrap(), b"ata");Sourceimpl<W> BufWriter<W>
impl<W> BufWriter<W>
1.0.0 ยท Sourcepub fn get_ref(&self) -> &W
pub fn get_ref(&self) -> &W
Gets a reference to the underlying writer.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let mut buffer = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
// we can use reference just like buffer
let reference = buffer.get_ref();1.0.0 ยท Sourcepub fn get_mut(&mut self) -> &mut W
pub fn get_mut(&mut self) -> &mut W
Gets a mutable reference to the underlying writer.
It is inadvisable to directly write to the underlying writer.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let mut buffer = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
// we can use reference just like buffer
let reference = buffer.get_mut();1.37.0 ยท Sourcepub fn buffer(&self) -> &[u8] โ
pub fn buffer(&self) -> &[u8] โ
Returns a reference to the internally buffered data.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let buf_writer = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
// See how many bytes are currently buffered
let bytes_buffered = buf_writer.buffer().len();1.46.0 ยท Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of bytes the internal buffer can hold without flushing.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let buf_writer = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
// Check the capacity of the inner buffer
let capacity = buf_writer.capacity();
// Calculate how many bytes can be written without flushing
let without_flush = capacity - buf_writer.buffer().len();Trait Implementations
impl<T> IoSafe for BufWriter<T>where
T: IoSafe + Write,
1.0.0 ยท Sourceimpl<W> Seek for BufWriter<W>
impl<W> Seek for BufWriter<W>
Sourcefn seek(&mut self, pos: SeekFrom) -> Result<u64, Error>
fn seek(&mut self, pos: SeekFrom) -> Result<u64, Error>
Seek to the offset, in bytes, in the underlying writer.
Seeking always writes out the internal buffer before seeking.
1.55.0 ยท Sourcefn rewind(&mut self) -> Result<(), Error>
fn rewind(&mut self) -> Result<(), Error>
Sourcefn stream_len(&mut self) -> Result<u64, Error>
fn stream_len(&mut self) -> Result<u64, Error>
seek_stream_len)1.0.0 ยท Sourceimpl<W> Write for BufWriter<W>
impl<W> Write for BufWriter<W>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Error>
fn write(&mut self, buf: &[u8]) -> Result<usize, Error>
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
can_vector)Sourcefn flush(&mut self) -> Result<(), Error>
fn flush(&mut self) -> Result<(), Error>
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
write_all_vectored)Auto Trait Implementations
impl<W> Freeze for BufWriter<W>
impl<W> RefUnwindSafe for BufWriter<W>where
W: RefUnwindSafe + ?Sized,
impl<W> Send for BufWriter<W>
impl<W> Sync for BufWriter<W>
impl<W> Unpin for BufWriter<W>
impl<W> UnsafeUnpin for BufWriter<W>where
W: UnsafeUnpin + ?Sized,
impl<W> UnwindSafe for BufWriter<W>where
W: UnwindSafe + ?Sized,